package app

import (
	"os"
	"path"
	"strings"

	"coopcloud.tech/abra/cli/internal"
	"coopcloud.tech/abra/pkg/autocomplete"
	"coopcloud.tech/abra/pkg/config"
	"coopcloud.tech/abra/pkg/runtime"
	"github.com/sirupsen/logrus"
	"github.com/urfave/cli"
)

var appCheckCommand = cli.Command{
	Name:      "check",
	Aliases:   []string{"chk"},
	Usage:     "Check if app is configured correctly",
	ArgsUsage: "<domain>",
	Flags: []cli.Flag{
		internal.DebugFlag,
		internal.OfflineFlag,
	},
	Before: internal.SubCommandBefore,
	Action: func(c *cli.Context) error {
		conf := runtime.New(runtime.WithOffline(internal.Offline))
		app := internal.ValidateApp(c, conf)

		envSamplePath := path.Join(config.RECIPES_DIR, app.Recipe, ".env.sample")
		if _, err := os.Stat(envSamplePath); err != nil {
			if os.IsNotExist(err) {
				logrus.Fatalf("%s does not exist?", envSamplePath)
			}
			logrus.Fatal(err)
		}

		envSample, err := config.ReadEnv(envSamplePath)
		if err != nil {
			logrus.Fatal(err)
		}

		var missing []string
		for k := range envSample {
			if _, ok := app.Env[k]; !ok {
				missing = append(missing, k)
			}
		}

		if len(missing) > 0 {
			missingEnvVars := strings.Join(missing, ", ")
			logrus.Fatalf("%s is missing %s", app.Path, missingEnvVars)
		}

		logrus.Infof("all necessary environment variables defined for %s", app.Name)

		return nil
	},
	BashComplete: autocomplete.AppNameComplete,
}
